@@ -10,14 +10,8 @@ open Format
 open Util
 open Pp
 open Term
-#if COQVERSION >= 81500
 open Tacmach
-#else
-open Tacmach.New
-#endif
-#if COQVERSION >= 81600
 open Gramlib
-#endif
 open Names
 open Coqlib
 open Libnames
@@ -41,9 +35,7 @@ let generalize = Tactics.generalize
 open Ltac_plugin
 open EConstr
 
-#if COQVERSION >= 81300
 let is_global = isRefX
-#endif
 
 #if COQVERSION >= 81800
 let is_global t1 t2 = is_global !global_env t1 t2
@@ -66,74 +58,24 @@ let eq_constr t1 t2 = eq_constr !global_evd t1 t2
 let pr_constr t =
   Printer.pr_econstr_env !global_env !global_evd t
 
-#if COQVERSION >= 81500
 let constr_of_global gr = UnivGen.constr_of_monomorphic_global (Global.env ()) gr
-#elif COQVERSION >= 81000
-let constr_of_global = UnivGen.constr_of_monomorphic_global
-#elif COQVERSION >= 80900
-let constr_of_global = UnivGen.constr_of_global
-#else
-let constr_of_global = Universes.constr_of_global
-#endif
 
-#if COQVERSION >= 81000
 let binder_name = Context.binder_name
-#else
-let binder_name x = x
-#endif
 
 #if COQVERSION >= 81700
 let refine_no_check = Tactics.exact_no_check
-#elif COQVERSION >= 81300
-let refine_no_check t =
-  Logic.refiner ~check:false (EConstr.Unsafe.to_constr t)
-#elif COQVERSION >= 81200
-let refine_no_check t =
-  Refiner.refiner ~check:false (EConstr.Unsafe.to_constr t)
-#elif COQVERSION >= 81000
-let refine_no_check t =
-  Proofview.V82.tactic (fun gl -> Refiner.refiner ~check:false (EConstr.Unsafe.to_constr t) gl)
 #else
 let refine_no_check t =
-  Proofview.V82.tactic (fun gl -> Tacmach.refine_no_check t gl)
+  Logic.refiner ~check:false (EConstr.Unsafe.to_constr t)
 #endif
 
 let map_constr f t =
   EConstr.map !global_evd f t
 
-#if COQVERSION >= 81500
 let convert_concl_no_check a =
   Tactics.convert_concl ~cast:false ~check:false a Constr.DEFAULTcast
 
-let tclTHEN = Tacticals.tclTHEN
-#else
-let convert_concl_no_check a =
-  Tactics.convert_concl ~check:false a Constr.DEFAULTcast
-
-let tclTHEN = Tacticals.New.tclTHEN
-#endif
-
-#if COQVERSION < 80900
-let parse_entry e s = Pcoq.Gram.entry_parse e (Pcoq.Gram.parsable s)
-#else
 let parse_entry e s = Pcoq.Entry.parse e (Pcoq.Parsable.make s)
-#endif
-
-#if COQVERSION < 81100
-
-let coq_reference t1 t2 =
-  let th = lazy (coq_reference t1 t2) in
-  fun x -> lazy (Lazy.force th x)
-
-let find_reference t1 t2 =
-  let th = lazy (find_reference t1 t2) in
-  fun x -> lazy (Lazy.force th x)
-
-let is_global c t = is_global (Lazy.force c) t
-
-let constr_of_global f = of_constr (constr_of_global (Lazy.force f))
-
-#else
 
 let find_reference t1 t2 x =
   lazy (of_constr (constr_of_global (gen_reference_in_modules t1 [t2] x)))
@@ -144,23 +86,13 @@ let is_global c t = eq_constr (Lazy.force c) t
 
 let constr_of_global f = Lazy.force f
 
-#endif
-
-#if COQVERSION >= 81600
 let __coq_plugin_name = "coq-gappa.tactic"
-#else
-let __coq_plugin_name = "gappatac"
-#endif
 
 let _ = Mltop.add_known_module __coq_plugin_name
 
 let debug = ref false
 
-#if COQVERSION < 81300
-open Big_int
-#else
 open Big_int_Z
-#endif
 
 (* 1. gappa syntax trees and output *)
 
@@ -583,8 +515,8 @@ let gappa_quote =
     (*Pp.msgerrnl (pr_constr e);*)
     Hashtbl.clear var_terms;
     var_list := [];
-    tclTHEN
-      (tclTHEN
+    Tacticals.tclTHEN
+      (Tacticals.tclTHEN
         (generalize (List.map (fun (n, _) -> mkVar n) (List.rev l)))
         (Tactics.keep []))
       (convert_concl_no_check e)
